netapp_ontap.models.dcn_hardware_cpu API documentation
Description: Copyright &copy; 2026 NetApp Inc. All rights reserved …

# Module `netapp_ontap.models.dcn_hardware_cpu`

Copyright © 2026 NetApp Inc. All rights reserved.

This file has been automatically generated based on the ONTAP REST API documentation.

## Classes

`class DcnHardwareCpuSchema (*, only: types.StrSequenceOrSet | None = None, exclude: types.StrSequenceOrSet = (), many: bool | None = None, context: dict | None = None, load_only: types.StrSequenceOrSet = (), dump_only: types.StrSequenceOrSet = (), partial: bool | types.StrSequenceOrSet | None = None, unknown: str | None = None)`

  The fields of the DcnHardwareCpu object

  ### Ancestors

  - netapp_ontap.resource.ResourceSchema
  - marshmallow.schema.Schema
  - marshmallow.base.SchemaABC
  - abc.ABC

  ### Class variables

  `count: Size GET`

    Number count of CPUs on the node.

    Example: 20

  `firmware_release: str GET`

    Firmware release number. Defined by the CPU manufacturer.

  `memory_size: Size GET`

    GPU Memory available on the node, in bytes.

    Example: 1024000000

  `processor: str GET`

    CPU type on the node.